Documentation
¶
Index ¶
- func InitTypeRegistry()
- func MakeInstance(name string) node.Node
- type Addition
- func (n *Addition) GetId() string
- func (n *Addition) GetInput(i int) *node.Port
- func (n *Addition) GetInputs() []node.Port
- func (n *Addition) GetOutput(i int) *node.Port
- func (n *Addition) GetOutputs() []node.Port
- func (n *Addition) GetPosition() node.Location
- func (n *Addition) Init(c chan node.Result, id string)
- func (n *Addition) Solve()
- type Comp
- type Io
- type Multiplication
- func (n *Multiplication) GetId() string
- func (n *Multiplication) GetInput(i int) *node.Port
- func (n *Multiplication) GetInputs() []node.Port
- func (n *Multiplication) GetOutput(i int) *node.Port
- func (n *Multiplication) GetOutputs() []node.Port
- func (n *Multiplication) GetPosition() node.Location
- func (n *Multiplication) Init(c chan node.Result, id string)
- func (n *Multiplication) Solve()
- type Number
- func (n *Number) GetId() string
- func (n *Number) GetInput(i int) *node.Port
- func (n *Number) GetInputs() []node.Port
- func (n *Number) GetOutput(i int) *node.Port
- func (n *Number) GetOutputs() []node.Port
- func (n *Number) GetPosition() node.Location
- func (n *Number) Init(c chan node.Result, id string)
- func (n *Number) Solve()
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func InitTypeRegistry ¶
func InitTypeRegistry()
InitTypeRegistry loads all available nodes into the registry TODO: should use reflection to get implemented types
func MakeInstance ¶
MakeInstance creates a component by name
Types ¶
type Comp ¶
func GetComponents ¶
func GetComponents() []Comp
GetComponents returns a list of all available components and their properties
type Multiplication ¶
type Multiplication struct {
Inputs []node.Port
Outputs []node.Port
Id string
Position node.Location
}
func (*Multiplication) GetId ¶
func (n *Multiplication) GetId() string
func (*Multiplication) GetInputs ¶
func (n *Multiplication) GetInputs() []node.Port
func (*Multiplication) GetOutputs ¶
func (n *Multiplication) GetOutputs() []node.Port
func (*Multiplication) GetPosition ¶
func (n *Multiplication) GetPosition() node.Location
func (*Multiplication) Solve ¶
func (n *Multiplication) Solve()
Click to show internal directories.
Click to hide internal directories.