Documentation
¶
Index ¶
- func NewEdge(from *Port, to *Port)
- type Edge
- type Location
- type Node
- type Port
- func (p *Port) AddIncomingEdge(e *Edge)
- func (p *Port) AddOutgoingEdge(e Edge)
- func (p *Port) AwaitValue() interface{}
- func (p *Port) GetIncomingChannel(edge int) (error, chan interface{})
- func (p *Port) GetIncomingEdges() []*Edge
- func (p *Port) GetValue() interface{}
- func (p *Port) SetValue(val interface{})
- type Result
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
Types ¶
type Port ¶
type Port struct {
Parent Node
Name string
Type reflect.Kind
HasValue bool
Outgoing []Edge
Incoming []*Edge
Optional bool
ResultChannel chan Result
// contains filtered or unexported fields
}
Generic Port Interface
func (*Port) AddIncomingEdge ¶
AddIncomingEdge adds and edge to a port as incoming
func (*Port) AddOutgoingEdge ¶
AddOutgoingEdge adds an edge to a port as outgoing
func (*Port) AwaitValue ¶
func (p *Port) AwaitValue() interface{}
AwaitValue awaits the value of a channel
func (*Port) GetIncomingChannel ¶
GetIncomingChannel gets an incoming channel for a specific edge
func (*Port) GetIncomingEdges ¶
GetIncomingEdges returns all incoming edges
Click to show internal directories.
Click to hide internal directories.